@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2023 Joël Krähemann
+ * Copyright (C) 2005-2024 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -25,6 +25,8 @@
 
 #include <ags/libags.h>
 
+#include <ags/audio/ags_audio_buffer_util.h>
+
 #include <sndfile.h>
 
 G_BEGIN_DECLS
@@ -83,6 +85,8 @@ struct _AgsSndfile
 
   SF_INFO *info;
   SNDFILE *file;
+
+  AgsAudioBufferUtil *audio_buffer_util;
 };
 
 struct _AgsSndfileClass
